Emperor’s public API — Emperor 0.9.51-dev documentation

# Emperor’s public API

## Emperor 3D PCoA viewer (`emperor`)

This module provides an objects and functions to interact and visualize a set of coordinates using the Emperor interface user interface. The Emperor class, and the functions present here are all intended to be compatible with the Jupyter notebook.

### Classes

`Emperor`(ordination, mapping_file[, ...]) | Display principal coordinates analysis plots

### Functions

`nbinstall`([overwrite, user, prefix]) | Copies resources to the ‘/nbextensions’ folder in your IPython directory
`scatterplot`(df[, x, y, z, remote]) | Create an Emperor scatter plot from a Pandas DataFrame